-----------------------------------------------------------------------------------------------
-- Client Lua Script for FlashyLoot
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "GameLib"
require "Apollo"
 
-----------------------------------------------------------------------------------------------
-- FlashyLoot Module Definition
-----------------------------------------------------------------------------------------------
local FlashyLoot = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function FlashyLoot:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	self.bLocked = true

    return o
end

function FlashyLoot:Init()
	local bHasConfigureFunction = true
	local strConfigureButtonText = "FlashyLoot"
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- FlashyLoot OnLoad
-----------------------------------------------------------------------------------------------
function FlashyLoot:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("FlashyLoot.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	
end

-----------------------------------------------------------------------------------------------
-- FlashyLoot OnDocLoaded
-----------------------------------------------------------------------------------------------
function FlashyLoot:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    
		--Settings Window
		self.wndMain = Apollo.LoadForm(self.xmlDoc, "FlashyLootForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		--Loot Icon
		self.wndLootIcon = Apollo.LoadForm(self.xmlDoc, "LootIcon", nil, self)
		if self.wndLootIcon == nil then
			Apollo.AddAddonErrorText(self, "Could not load the loot icon for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)
		self.wndLootIcon:Show(false, true)
		
		--self.locSavedLocation = self.wndLootIcon:GetLocation()

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("flashyloot", "OnFlashyLootOn", self)
		Apollo.RegisterSlashCommand("flashylootunlock", "OnFlashyLootUnlock", self)
		Apollo.RegisterSlashCommand("flashylootlock", "OnFlashyLootLock", self)
		Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)
		Apollo.RegisterEventHandler("WindowManagementReady", "OnWindowManagementReady", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- FlashyLoot OnSave/OnRestore
-----------------------------------------------------------------------------------------------
function FlashyLoot:onSave(saveLevel)
	--local savedData = {}
	--savedData.locSavedLocation = self.locSavedLocation
  	--return savedData
end

function FlashyLoot:onRestore(saveLevel, savedData)
	--self.locSavedLocation = savedData.locSavedLocation
end

function FlashyLoot:OnWindowManagementReady()
	Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndLootIcon, strName = "LootIcon"})
end

-----------------------------------------------------------------------------------------------
-- FlashyLoot Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/flashyloot"
function FlashyLoot:OnFlashyLootOn()
	self.wndMain:Invoke() -- show the window
end

-- on SlashCommand "/flashylootunlock"
function FlashyLoot:OnFlashyLootUnlock()
	self.bLocked = false
	self.wndLootIcon:RemoveStyle("IgnoreMouse")
	self.wndLootIcon:AddStyle("Moveable")
	self.wndLootIcon:Show(true, true)
end

-- on SlashCommand "/flashylootlock"
function FlashyLoot:OnFlashyLootLock()
	self.bLocked = true
	self.wndLootIcon:AddStyle("IgnoreMouse")
	self.wndLootIcon:RemoveStyle("Moveable")
	self.wndLootIcon:Show(false, true)
	--self.locSavedLocation = self.wndLootIcon:GetLocation()
end

function FlashyLoot:OnTimer()
	if GameLib.CanVacuum() then
		self.wndLootIcon:Show(true, true)
		return
	end
	
	if self.bLocked then
		self.wndLootIcon:Show(false, true)
	end
end

-----------------------------------------------------------------------------------------------
-- FlashyLootForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function FlashyLoot:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function FlashyLoot:OnCancel()
	self.wndMain:Close() -- hide the window
end

function FlashyLoot:OnConfigure()
	self.wndMain:Invoke()
end

-----------------------------------------------------------------------------------------------
-- FlashyLoot Instance
-----------------------------------------------------------------------------------------------
local FlashyLootInst = FlashyLoot:new()
FlashyLootInst:Init()
